==> tencentcloud-sdk-java-3.1.1000-sources.jar: com/tencentcloudapi/lke/v20231130/models/DescribeRobotBizIDByAppKeyRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.lke.v20231130.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeRobotBizIDByAppKeyRequest extends AbstractModel {

    /**
    * 机器人appkey
    */
    @SerializedName("AppKey")
    @Expose
    private String AppKey;

    /**
     * Get 机器人appkey 
     * @return AppKey 机器人appkey
     */
    public String getAppKey() {
        return this.AppKey;
    }

    /**
     * Set 机器人appkey
     * @param AppKey 机器人appkey
     */
    public void setAppKey(String AppKey) {
        this.AppKey = AppKey;
    }

    public DescribeRobotBizIDByAppKeyRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeRobotBizIDByAppKeyRequest(DescribeRobotBizIDByAppKeyRequest source) {
        if (source.AppKey != null) {
            this.AppKey = new String(source.AppKey);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "AppKey", this.AppKey);

    }
}

==> tencentcloud-sdk-java-3.1.1130-sources.jar: com/tencentcloudapi/lke/v20231130/models/DescribeRobotBizIDByAppKeyRequest.java <==
/*
 * Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.tencentcloudapi.lke.v20231130.models;

import com.tencentcloudapi.common.AbstractModel;
import com.tencentcloudapi.common.SSEResponseModel;
import com.google.gson.annotations.SerializedName;
import com.google.gson.annotations.Expose;
import java.util.HashMap;

public class DescribeRobotBizIDByAppKeyRequest extends AbstractModel {

    /**
    * 应用appkey
    */
    @SerializedName("AppKey")
    @Expose
    private String AppKey;

    /**
     * Get 应用appkey 
     * @return AppKey 应用appkey
     */
    public String getAppKey() {
        return this.AppKey;
    }

    /**
     * Set 应用appkey
     * @param AppKey 应用appkey
     */
    public void setAppKey(String AppKey) {
        this.AppKey = AppKey;
    }

    public DescribeRobotBizIDByAppKeyRequest() {
    }

    /**
     * NOTE: Any ambiguous key set via .set("AnyKey", "value") will be a shallow copy,
     *       and any explicit key, i.e Foo, set via .setFoo("value") will be a deep copy.
     */
    public DescribeRobotBizIDByAppKeyRequest(DescribeRobotBizIDByAppKeyRequest source) {
        if (source.AppKey != null) {
            this.AppKey = new String(source.AppKey);
        }
    }


    /**
     * Internal implementation, normal users should not use it.
     */
    public void toMap(HashMap<String, String> map, String prefix) {
        this.setParamSimple(map, prefix + "AppKey", this.AppKey);

    }
}
